
.. image:: ../logo_flat.png

*µ*\Grid, MPI-parallel regular grids
====================================

*µ*\Grid is a C++17 library for discrete representation of fields on structured
grids, with Python bindings. It provides efficient data structures and algorithms
for solving partial differential equations on regular grids, with support for
MPI parallelization and GPU acceleration.

Key features include field collections for managing grid data, a built-in FFT
engine with MPI-parallel support, convolution operators for spectral methods,
domain decomposition with ghost cell communication, and NetCDF I/O.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Summary
   GettingStarted
   Python
   FFT
   GPU
   Operators
   Examples
   Cplusplus
   PythonAPI
   CplusplusAPI
   CodingConvention

*µ*\Grid is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public License as
published by the Free Software Foundation, either version 3, or (at
your option) any later version.

*µ*\Grid is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with *µ*\Grid; see the file COPYING. If not, write to the
Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
